@@ -10,6 +10,7 @@ from django.db import transaction
 from django.utils.timezone import now as tz_now
 
 from command_log.models import ManagementCommandLog, ManagementCommandLogQuerySet
+from command_log.utils.signals import MODEL_SIGNALS, disable_signals
 
 logger = logging.getLogger("command_log")
 
@@ -70,6 +71,11 @@ class LoggedCommand(BaseCommand):
             dest="no_truncate",
             help="Override truncation_interval to set log to never expire.",
         )
+        parser.add_argument(
+            "--disable-model-signals",
+            action="store_true",
+            help="Disable all model signals while running this command.",
+        )
 
     @property
     def app_name(self) -> str:
@@ -101,14 +107,21 @@ class LoggedCommand(BaseCommand):
     def handle(self, *args: Any, **options: Any) -> None:
         """Run the do_command method and log the output."""
         self.no_truncate = options["no_truncate"]
+        disabled_signals = MODEL_SIGNALS if options["disable_model_signals"] else ()
+
         log = ManagementCommandLog(
             app_name=self.app_name,
             command_name=self.command_name,
             truncate_at=self.truncate_at,
         )
         log.start()
+
         try:
-            output = self.do_command(*args, **options)
+            # Note: only disable signals during self.do_command():
+            # --disable-model-signals should leave any signals generated by
+            # ManagementCommandLog intact.
+            with disable_signals(disabled_signals):
+                output = self.do_command(*args, **options)
             log.stop(output=str(output), exit_code=log.EXIT_CODE_SUCCESS)
         except PartialCompletionError as ex:
             logger.warning("Command partially completed")
